<?php

namespace BYDAuto\Commands;

use App\Mail\HelloMail;
use App\Notifications\HelloNotification;
use BYDAuto\Models\Contact;
use BYDAuto\Models\Testdrive;
use Illuminate\Console\Command;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Support\Facades\Mail;

class BYDAutoCommand extends Command
{
    protected $signature = 'bydauto {action?}';

    protected $description = 'BYDAuto Command';

    public function handle()
    {
        $action = $this->argument('action');
        $method = "action_{$action}";
        if (method_exists($this, $method)) {
            $this->{$method}();
        } else {
            $this->error("不支持的操作 {$action}");
        }
    }

    public function action_mail_test()
    {
        $users = [
            ['remark' => '陈结婷', 'email' => '402917192@qq.com'],
            ['remark' => '何汝立', 'email' => '136111753@qq.com'],
            ['remark' => '刘梦吉', 'email' => '842681856@qq.com'],
            ['remark' => '詹林钦', 'email' => '1908995103@qq.com'],
            ['remark' => '王迎迎', 'email' => '1123724727@qq.com'],
            ['remark' => '曾嘉威', 'email' => '2951015145@qq.com'],
            ['remark' => '刘甜甜', 'email' => '941605227@qq.com'],
            ['remark' => '符志勇', 'email' => '583493528@qq.com'],
            ['remark' => '廖瑞莹', 'email' => '42794345@qq.com'],
            ['remark' => '刘志伟', 'email' => '857284399@qq.com'],
            ['remark' => '张光东', 'email' => '543396628@qq.com'],
            ['remark' => '赖俊文', 'email' => '591908300@qq.com'],
            ['remark' => '刘星宇', 'email' => '1776807891@qq.com'],
            ['remark' => '郑立佳', 'email' => '315783857@qq.com'],
            ['remark' => '郑广勇', 'email' => '973978463@qq.com'],
            ['remark' => '湛善栋', 'email' => '838406377@qq.com']
        ];

        $message = new HelloMail(name: '张三');
        Mail::to('sam@ifme.in')->send($message);
    }

    public function action_init()
    {
        $this->call('db:wipe');
        $this->call('migrate');
    }

    public function action_testdrive()
    {
        $items = Testdrive::query()->orderBy('id', 'desc')->get();
        $this->table(['id', 'date_created', 'status', 'name', 'mobile'], $items->map(function (Testdrive $v) {
            return [$v->id, $v->date_created, $v->status, $v->name, $v->mobile];
        }));
    }

    public function action_contact()
    {
        $items = Contact::all();
        $this->table(['id', 'email', 'remark', 'status'], $items->map(function (Contact $v) {
            return [$v->id, $v->email, $v->remark, $v->status];
        }));
    }

    public function action_contact_add()
    {
        $data['email'] = $this->ask('Email');
        $data['remark'] = $this->ask('Remark');
        $data['status'] = Contact::STATUS_PUBLISHED;

        $contact = new Contact($data);
        $contact->save();

        $this->info('Contact added');
    }
}
